@@ -23,6 +23,6 @@ int main(int, char *[]) {
         .set<PortableType>({10, 20});
 
     // Convert PortableType component to flecs expression string
-    const PortableType *ptr = e.get<PortableType>();
-    std::cout << ecs.to_expr(ptr).c_str() << "\n"; // {i32: 10, inptr: 20}
+    const PortableType& ptr = e.get<PortableType>();
+    std::cout << ecs.to_expr(&ptr).c_str() << "\n"; // {i32: 10, inptr: 20}
 }
