@@ -26,26 +26,10 @@ inline const Self& entity_builder<Self>::insert(const Func& func) const  {
     return to_base();
 }
 
-template <typename T, if_t< is_enum<T>::value > >
-const T* entity_view::get() const {
-    entity_t r = _::type<T>::id(world_);
-    entity_t c = ecs_get_target(world_, id_, r, 0);
-
-    if (c) {
-#ifdef FLECS_META
-        using U = typename std::underlying_type<T>::type;
-        const T* v = static_cast<const T*>(
-            ecs_get_id(world_, c, ecs_pair(flecs::Constant, _::type<U>::id(world_))));
-        ecs_assert(v != NULL, ECS_INTERNAL_ERROR, "missing enum constant value");
-        return v;
-#else
-        // Fallback if we don't have the reflection addon
-        return static_cast<const T*>(ecs_get_id(world_, id_, r));
-#endif
-    } else {
-        // If there is no matching pair for (r, *), try just r
-        return static_cast<const T*>(ecs_get_id(world_, id_, r));
-    }
+template<typename Enum>
+inline Enum entity_view::get_constant() const {
+    flecs::entity tgt = this->target<Enum>();
+    return tgt.to_constant<Enum>();
 }
 
 template<typename First>
@@ -82,7 +66,7 @@ inline flecs::entity entity_view::target_for(flecs::entity_t relationship) const
 }
 
 inline flecs::entity entity_view::parent() const {
-    return target(flecs::ChildOf);
+    return flecs::entity(world_, ecs_get_parent(world_, id_));
 }
 
 inline flecs::entity entity_view::mut(const flecs::world& stage) const {
