@@ -5,8 +5,6 @@
 
 #pragma once
 
-#include <stdio.h>
-
 namespace flecs {
 
 /**
@@ -27,6 +25,15 @@ using serialize_t = ecs_meta_serialize_t;
 template <typename T>
 using serialize = int(*)(const serializer *, const T*);
 
+/** Type safe variant of serialize_member function */
+template <typename T>
+using serialize_member = int(*)(const serializer *, const T*, const char* name);
+
+/** Type safe variant of serialize_element function */
+template <typename T>
+using serialize_element = int(*)(const serializer *, const T*, size_t element);
+
+
 /** Type safe interface for opaque types */
 template <typename T, typename ElemType = void>
 struct opaque {
@@ -50,6 +57,22 @@ struct opaque {
         return *this;
     }
 
+    /** Serialize member function */
+    opaque& serialize_member(flecs::serialize_member<T> func) {
+        this->desc.type.serialize_member =
+            reinterpret_cast<decltype(
+                this->desc.type.serialize_member)>(func);
+        return *this;
+    }
+
+    /** Serialize element function */
+    opaque& serialize_element(flecs::serialize_element<T> func) {
+        this->desc.type.serialize_element =
+            reinterpret_cast<decltype(
+                this->desc.type.serialize_element)>(func);
+        return *this;
+    }
+
     /** Assign bool value */
     opaque& assign_bool(void (*func)(T *dst, bool value)) {
         this->desc.type.assign_bool =
