@@ -137,7 +137,7 @@ using base_arg_type_t = typename base_arg_type<T>::type;
 template <typename T>
 struct is_actual {
     static constexpr bool value =
-        std::is_same<T, actual_type_t<T> >::value && !is_enum<T>::value;
+        std::is_same<T, actual_type_t<T> >::value;
 };
 
 } // flecs
