@@ -146,7 +146,6 @@ void flecs_map_rehash(
     if (count < 2) {
         count = 2;
     }
-    ecs_assert(count > map->bucket_count, ECS_INTERNAL_ERROR, NULL);
     
     int32_t old_count = map->bucket_count;
     ecs_bucket_t *buckets = map->buckets, *b, *end = ECS_BUCKET_END(buckets, old_count);
@@ -172,40 +171,15 @@ void flecs_map_rehash(
     ECS_MAP_FREE_N(map->allocator, ecs_bucket_t, old_count, buckets);
 }
 
-void ecs_map_params_init(
-    ecs_map_params_t *params,
-    ecs_allocator_t *allocator)
-{
-    params->allocator = allocator;
-}
-
-void ecs_map_init_w_params(
-    ecs_map_t *result,
-    ecs_map_params_t *params)
-{
-    ecs_os_zeromem(result);
-
-    result->allocator = params->allocator;
-
-    flecs_map_rehash(result, 0);
-}
-
-void ecs_map_init_w_params_if(
-    ecs_map_t *result,
-    ecs_map_params_t *params)
-{
-    if (!ecs_map_is_init(result)) {
-        ecs_map_init_w_params(result, params);
-    }
-}
-
 void ecs_map_init(
     ecs_map_t *result,
     ecs_allocator_t *allocator)
 {
-    ecs_map_init_w_params(result, &(ecs_map_params_t) {
-        .allocator = allocator
-    });
+    ecs_os_zeromem(result);
+
+    result->allocator = allocator;
+
+    flecs_map_rehash(result, 0);
 }
 
 void ecs_map_init_if(
@@ -270,6 +244,10 @@ void ecs_map_insert(
 
     ecs_bucket_t *bucket = flecs_map_get_bucket(map, key);
     flecs_map_bucket_add(map->allocator, bucket, key)[0] = value;
+
+#ifdef FLECS_DEBUG
+    ecs_os_linc(&map->change_count);
+#endif
 }
 
 void* ecs_map_insert_alloc(
@@ -302,6 +280,11 @@ ecs_map_val_t* ecs_map_ensure(
 
     ecs_map_val_t* v = flecs_map_bucket_add(map->allocator, bucket, key);
     *v = 0;
+
+#ifdef FLECS_DEBUG
+    ecs_os_linc(&map->change_count);
+#endif
+
     return v;
 }
 
@@ -324,9 +307,23 @@ ecs_map_val_t ecs_map_remove(
     ecs_map_t *map,
     ecs_map_key_t key)
 {
+#ifdef FLECS_DEBUG
+    if (map->last_iterated != key) {
+        ecs_os_linc(&map->change_count);
+    }
+#endif    
     return flecs_map_bucket_remove(map, flecs_map_get_bucket(map, key), key);
 }
 
+void ecs_map_reclaim(
+    ecs_map_t *map)
+{
+    int32_t tgt_bucket_count = flecs_map_get_bucket_count(map->count - 1);
+    if (tgt_bucket_count != map->bucket_count) {
+        flecs_map_rehash(map, tgt_bucket_count);
+    }
+}
+
 void ecs_map_remove_free(
     ecs_map_t *map,
     ecs_map_key_t key)
@@ -350,6 +347,10 @@ void ecs_map_clear(
     map->bucket_count = 0;
     map->count = 0;
     flecs_map_rehash(map, 2);
+
+#ifdef FLECS_DEBUG
+    ecs_os_linc(&map->change_count);
+#endif
 }
 
 ecs_map_iter_t ecs_map_iter(
@@ -359,19 +360,46 @@ ecs_map_iter_t ecs_map_iter(
         return (ecs_map_iter_t){
             .map = map,
             .bucket = NULL,
-            .entry = NULL
+            .entry = NULL,
+#ifdef FLECS_DEBUG
+            .change_count = map->change_count
+#endif
         };
     } else {
         return (ecs_map_iter_t){ 0 };
     }
 }
 
+bool ecs_map_iter_valid(
+    ecs_map_iter_t *iter)
+{
+    const ecs_map_t *map = iter->map;
+    if (!map) {
+        return false;
+    }
+
+#ifdef FLECS_DEBUG
+    if (map->change_count != iter->change_count) {
+        return false;
+    }
+#endif
+
+    return true;
+}
+
 bool ecs_map_next(
     ecs_map_iter_t *iter)
 {
     const ecs_map_t *map = iter->map;
+    if (!map) {
+        return false;
+    }
+
+    ecs_dbg_assert(map->change_count == iter->change_count, ECS_INVALID_PARAMETER, 
+        "map cannot be modified while it is being iterated");
+
     ecs_bucket_t *end;
-    if (!map || (iter->bucket == (end = &map->buckets[map->bucket_count]))) {
+    if (iter->bucket == (end = &map->buckets[map->bucket_count])) {
         return false;
     }
 
@@ -403,6 +431,12 @@ bool ecs_map_next(
     iter->entry = entry->next;
     iter->res = &entry->key;
 
+#ifdef FLECS_DEBUG
+    /* Safe, only used for detecting if an element got removed that's not the
+     * currently iterated element. */
+    ECS_CONST_CAST(ecs_map_t*, map)->last_iterated = entry->key;
+#endif
+
     return true;
 }
 
