@@ -14,6 +14,39 @@ void ecs_vec_init(
     ecs_vec_init_w_dbg_info(allocator, v, size, elem_count, NULL);
 }
 
+static
+void* flecs_vec_alloc(
+    struct ecs_allocator_t *allocator,
+    ecs_size_t size,
+    int32_t elem_count,
+    const char *type_name)
+{
+    (void)type_name;
+    if (elem_count) {
+        if (allocator) {
+            return flecs_alloc_w_dbg_info(
+                allocator, size * elem_count, type_name);
+        } else {
+            return ecs_os_malloc(size * elem_count);
+        }
+    }
+    return NULL;
+}
+
+static
+void flecs_vec_free(
+    struct ecs_allocator_t *allocator,
+    ecs_size_t elem_size,
+    int32_t size,
+    void *ptr)
+{
+    if (allocator) {
+        flecs_free(allocator, elem_size * size, ptr);
+    } else {
+        ecs_os_free(ptr);
+    }
+}
+
 void ecs_vec_init_w_dbg_info(
     struct ecs_allocator_t *allocator,
     ecs_vec_t *v,
@@ -23,16 +56,8 @@ void ecs_vec_init_w_dbg_info(
 {
     (void)type_name;
     ecs_assert(size != 0, ECS_INVALID_PARAMETER, NULL);
-    v->array = NULL;
+    v->array = flecs_vec_alloc(allocator, size, elem_count, type_name);
     v->count = 0;
-    if (elem_count) {
-        if (allocator) {
-            v->array = flecs_alloc_w_dbg_info(
-                allocator, size * elem_count, type_name);
-        } else {
-            v->array = ecs_os_malloc(size * elem_count);
-        }
-    }
     v->size = elem_count;
 #ifdef FLECS_SANITIZE
     v->elem_size = size;
@@ -44,7 +69,8 @@ void ecs_vec_init_if(
     ecs_vec_t *vec,
     ecs_size_t size)
 {
-    ecs_san_assert(!vec->elem_size || vec->elem_size == size, ECS_INVALID_PARAMETER, NULL);
+    ecs_san_assert(!vec->elem_size || vec->elem_size == size, 
+        ECS_INVALID_PARAMETER, NULL);
     (void)vec;
     (void)size;
 #ifdef FLECS_SANITIZE
@@ -217,6 +243,18 @@ void ecs_vec_set_min_size(
     }
 }
 
+void ecs_vec_set_min_size_w_type_info(
+    struct ecs_allocator_t *allocator,
+    ecs_vec_t *vec,
+    ecs_size_t size,
+    int32_t elem_count,
+    const ecs_type_info_t *ti)
+{
+    if (elem_count > vec->size) {
+        ecs_vec_set_min_size_w_type_info(allocator, vec, size, elem_count, ti);
+    }
+}
+
 void ecs_vec_set_min_count(
     struct ecs_allocator_t *allocator,
     ecs_vec_t *vec,
@@ -243,12 +281,28 @@ void ecs_vec_set_min_count_zeromem(
     }
 }
 
+void ecs_vec_set_min_count_w_type_info(
+    struct ecs_allocator_t *allocator,
+    ecs_vec_t *vec,
+    ecs_size_t size,
+    int32_t elem_count,
+    const ecs_type_info_t *ti)
+{
+    int32_t count = vec->count;
+    if (count < elem_count) {
+        ecs_vec_set_count_w_type_info(allocator, vec, size, elem_count, ti);
+    }
+}
+
 void ecs_vec_set_count(
     ecs_allocator_t *allocator,
     ecs_vec_t *v,
     ecs_size_t size,
     int32_t elem_count)
 {
+    ecs_assert(size != 0, ECS_INVALID_PARAMETER, NULL);
+    ecs_san_assert(v->elem_size != 0, ECS_INVALID_PARAMETER, 
+        "vector is not initialized");
     ecs_san_assert(size == v->elem_size, ECS_INVALID_PARAMETER, NULL);
     if (v->count != elem_count) {
         if (v->size < elem_count) {
@@ -259,6 +313,95 @@ void ecs_vec_set_count(
     }
 }
 
+void ecs_vec_set_count_w_type_info(
+    struct ecs_allocator_t *allocator,
+    ecs_vec_t *v,
+    ecs_size_t size,
+    int32_t elem_count,
+    const ecs_type_info_t *ti)
+{
+    ecs_assert(size != 0, ECS_INVALID_PARAMETER, NULL);
+    ecs_san_assert(v->elem_size != 0, ECS_INVALID_PARAMETER, 
+        "vector is not initialized");
+    ecs_san_assert(size == v->elem_size, ECS_INVALID_PARAMETER, NULL);
+    ecs_assert(ti != NULL, ECS_INTERNAL_ERROR, NULL);
+
+    if (v->count == elem_count) {
+        return;
+    }
+
+    ecs_xtor_t ctor, dtor;
+    ecs_move_t move = ti->hooks.ctor_move_dtor;
+    if (!move) {
+        /* Trivial type, use regular set_count */
+        ecs_vec_set_count(allocator, v, size, elem_count);
+        return;
+    }
+
+    /* If array is large enough, we don't need to realloc. */
+    if (v->size > elem_count) {
+        if (elem_count > v->count) {
+            if ((ctor = ti->hooks.ctor)) {
+                void *ptr = ECS_ELEM(v->array, size, v->count);
+                ctor(ptr, elem_count - v->count, ti);
+            }
+        }
+
+        if (elem_count < v->count) {
+            if ((dtor = ti->hooks.dtor)) {
+                void *ptr = ECS_ELEM(v->array, size, elem_count);
+                dtor(ptr, v->count - elem_count, ti);
+            }
+        }
+
+        v->count = elem_count;
+        return;
+    }
+
+    /* Resize array. We can't use realloc because we need to call the move hook
+     * from the old to the new memory. */
+
+    /* Round up to next power of 2 so we don't allocate for each new element */
+    ecs_size_t new_size = flecs_next_pow_of_2(elem_count);
+
+    void *array = NULL;
+    #ifdef FLECS_SANITIZE
+    array = flecs_vec_alloc(allocator, size, new_size, v->type_name);
+    #else
+    array = flecs_vec_alloc(allocator, size, new_size, NULL);
+    #endif
+
+    int32_t move_count = elem_count;
+    if (move_count > v->count) {
+        move_count = v->count;
+    }
+
+    /* Move elements over to new array */
+    move(array, v->array, move_count, ti);
+
+    /* Destruct remaining elements in old array, if any */
+    if (move_count < v->count) {
+        if ((dtor = ti->hooks.dtor)) {
+            void *ptr = ECS_ELEM(v->array, size, move_count);
+            dtor(ptr, v->count - move_count, ti);
+        }
+    }
+
+    /* Construct new elements, if any */
+    if (move_count < elem_count) {
+        if ((ctor = ti->hooks.ctor)) {
+            void *ptr = ECS_ELEM(array, size, move_count);
+            ctor(ptr, elem_count - move_count, ti);
+        }
+    }
+
+    flecs_vec_free(allocator, size, v->size, v->array);
+
+    v->array = array;
+    v->size = new_size;
+    v->count = elem_count;
+}
+
 void* ecs_vec_grow(
     ecs_allocator_t *allocator,
     ecs_vec_t *v,
@@ -266,7 +409,7 @@ void* ecs_vec_grow(
     int32_t elem_count)
 {
     ecs_san_assert(size == v->elem_size, ECS_INVALID_PARAMETER, NULL);
-    ecs_assert(elem_count > 0, ECS_INTERNAL_ERROR, NULL);
+    ecs_assert(elem_count >= 0, ECS_INTERNAL_ERROR, NULL);
     int32_t count = v->count;
     ecs_vec_set_count(allocator, v, size, count + elem_count);
     return ECS_ELEM(v->array, size, count);
