@@ -58,7 +58,9 @@ void ecs_ref_update(
 
     flecs_check_exclusive_world_access_read(world);
 
-    if (ref->table_version_fast == flecs_get_table_version_fast(world, ref->table_id)) {
+    if (ref->table_version_fast == flecs_get_table_version_fast(
+        world, ref->table_id)) 
+    {
         return;
     }
 
