@@ -81,11 +81,6 @@ struct ecs_component_record_t {
 
     /* Refcount */
     int32_t refcount;
-
-    /* Keep alive count. This count must be 0 when the component record is deleted. If
-     * it is not 0, an application attempted to delete an id that was still
-     * queried for. */
-    int32_t keep_alive;
 };
 
 /* Bootstrap cached id records */
@@ -101,6 +96,11 @@ ecs_component_record_t* flecs_components_ensure(
     ecs_world_t *world,
     ecs_id_t id);
 
+/* Like flecs_components_ensure, but creates only if world is not in threaded mode */
+ecs_component_record_t* flecs_components_try_ensure(
+    ecs_world_t *world,
+    ecs_id_t id);
+
 /* Increase refcount of component record */
 void flecs_component_claim(
     ecs_world_t *world,
@@ -167,4 +167,7 @@ void flecs_component_record_init_exclusive(
     ecs_world_t *world,
     ecs_component_record_t *cr);
 
+void flecs_component_shrink(
+    ecs_component_record_t *cr);
+
 #endif
