@@ -83,7 +83,7 @@ void Pipeline_system_order_same_phase(void) {
 
     ecs_progress(world, 1);
 
-    test_int(stats->systems_ran_frame, 3);
+    test_int(stats->systems_ran_total, 3);
     test_int(stats->merge_count_total, 1);
     test_int(stats->pipeline_build_count_total, 1);
 
@@ -116,7 +116,7 @@ void Pipeline_system_order_same_phase_after_disable(void) {
 
     ecs_progress(world, 1);
 
-    test_int(stats->systems_ran_frame, 3);
+    test_int(stats->systems_ran_total, 3);
     test_int(stats->merge_count_total, 1);
     test_int(stats->pipeline_build_count_total, 1);
 
@@ -144,7 +144,7 @@ void Pipeline_system_order_different_phase(void) {
 
     ecs_progress(world, 1);
 
-    test_int(stats->systems_ran_frame, 3);
+    test_int(stats->systems_ran_total, 3);
     test_int(stats->merge_count_total, 1);
     test_int(stats->pipeline_build_count_total, 1);
 
@@ -177,7 +177,7 @@ void Pipeline_system_order_different_phase_after_disable(void) {
 
     ecs_progress(world, 1);
 
-    test_int(stats->systems_ran_frame, 3);
+    test_int(stats->systems_ran_total, 3);
     test_int(stats->merge_count_total, 1);
     test_int(stats->pipeline_build_count_total, 1);
 
@@ -210,7 +210,7 @@ void Pipeline_system_order_same_phase_after_activate(void) {
 
     ecs_progress(world, 1);
 
-    test_int(stats->systems_ran_frame, 3);
+    test_int(stats->systems_ran_total, 3);
     test_int(stats->merge_count_total, 1);
     test_int(stats->pipeline_build_count_total, 1);
 
@@ -247,7 +247,7 @@ void Pipeline_system_order_different_phase_after_activate(void) {
 
     test_assert( !ecs_has_id(world, SysB, EcsEmpty));
 
-    test_int(stats->systems_ran_frame, 3);
+    test_int(stats->systems_ran_total, 3);
     test_int(stats->merge_count_total, 1);
     test_int(stats->pipeline_build_count_total, 1);
 
@@ -284,7 +284,7 @@ void Pipeline_system_order_after_new_system_lower_id(void) {
 
     ecs_progress(world, 1);
 
-    test_int(stats->systems_ran_frame, 3);
+    test_int(stats->systems_ran_total, 3);
     test_int(stats->merge_count_total, 1);
     test_int(stats->pipeline_build_count_total, 1);
 
@@ -321,7 +321,7 @@ void Pipeline_system_order_after_new_system_inbetween_id(void) {
 
     ecs_progress(world, 1);
 
-    test_int(stats->systems_ran_frame, 3);
+    test_int(stats->systems_ran_total, 3);
     test_int(stats->merge_count_total, 1);
     test_int(stats->pipeline_build_count_total, 1);
 
@@ -358,7 +358,7 @@ void Pipeline_system_order_after_new_system_higher_id(void) {
 
     ecs_progress(world, 1);
 
-    test_int(stats->systems_ran_frame, 3);
+    test_int(stats->systems_ran_total, 3);
     test_int(stats->merge_count_total, 1);
     test_int(stats->pipeline_build_count_total, 1);
 
@@ -447,7 +447,7 @@ void Pipeline_merge_after_staged_out(void) {
 
     ecs_progress(world, 1);
 
-    test_int(stats->systems_ran_frame, 2);
+    test_int(stats->systems_ran_total, 2);
     test_int(stats->merge_count_total, 2);
     test_int(stats->pipeline_build_count_total, 2);
 
@@ -475,7 +475,7 @@ void Pipeline_merge_after_not_out(void) {
 
     ecs_progress(world, 1);
 
-    test_int(stats->systems_ran_frame, 2);
+    test_int(stats->systems_ran_total, 2);
     test_int(stats->merge_count_total, 2);
     test_int(stats->pipeline_build_count_total, 2);
 
@@ -503,7 +503,7 @@ void Pipeline_no_merge_after_main_out(void) {
 
     ecs_progress(world, 1);
 
-    test_int(stats->systems_ran_frame, 2);
+    test_int(stats->systems_ran_total, 2);
     test_int(stats->merge_count_total, 1);
     test_int(stats->pipeline_build_count_total, 1);
 
@@ -533,7 +533,7 @@ void Pipeline_merge_after_staged_in_out(void) {
 
     ecs_progress(world, 1);
 
-    test_int(stats->systems_ran_frame, 2);
+    test_int(stats->systems_ran_total, 2);
     test_int(stats->merge_count_total, 2);
     test_int(stats->pipeline_build_count_total, 1);
 
@@ -561,7 +561,7 @@ void Pipeline_merge_after_staged_inout_main_implicit_inout(void) {
 
     ecs_progress(world, 1);
 
-    test_int(stats->systems_ran_frame, 1);
+    test_int(stats->systems_ran_total, 1);
     test_int(stats->merge_count_total, 1);
     test_int(stats->pipeline_build_count_total, 1);
 
@@ -583,7 +583,7 @@ void Pipeline_merge_after_staged_inout_main_inout(void) {
 
     ecs_progress(world, 1);
 
-    test_int(stats->systems_ran_frame, 2);
+    test_int(stats->systems_ran_total, 2);
     test_int(stats->merge_count_total, 2);
     test_int(stats->pipeline_build_count_total, 1);
 
@@ -611,7 +611,7 @@ void Pipeline_merge_after_staged_out_before_owned(void) {
 
     ecs_progress(world, 1);
 
-    test_int(stats->systems_ran_frame, 2);
+    test_int(stats->systems_ran_total, 2);
     test_int(stats->merge_count_total, 2);
     test_int(stats->pipeline_build_count_total, 2);
 
@@ -675,7 +675,7 @@ void Pipeline_run_pipeline(void) {
 
     ecs_progress(world, 0);
 
-    test_int(stats->systems_ran_frame, 3);
+    test_int(stats->systems_ran_total, 3);
     test_int(stats->merge_count_total, 1);
     test_int(stats->pipeline_build_count_total, 1);
 
