@@ -1797,3 +1797,45 @@ void SystemMisc_register_run_after_callback_ctx(void) {
     test_int(callback_ctx, 1);
     test_int(run_ctx, 1);
 }
+
+static void Run_w_query_next(ecs_iter_t *it) {
+    while (ecs_query_next(it)) {
+        probe_iter(it);
+    }
+
+    run_invoked ++;
+}
+
+void SystemMisc_run_w_query_next(void) {
+    ecs_world_t *world = ecs_init();
+
+    ECS_TAG(world, TagA);
+    ECS_TAG(world, TagB);
+
+    Probe ctx = {0};
+    ecs_entity_t system = ecs_system_init(world, &(ecs_system_desc_t){
+        .query.terms = {{ .id = TagA }},
+        .run = Run_w_query_next,
+        .callback = Dummy,
+        .ctx = &ctx,
+    });
+    test_assert(system != 0);
+
+    ecs_entity_t e1 = ecs_new_w(world, TagA);
+    ecs_entity_t e2 = ecs_new_w(world, TagA);
+    ecs_entity_t e3 = ecs_new_w(world, TagA);
+    ecs_add(world, e3, TagB); // 2 tables
+
+    ecs_run(world, system, 0, NULL);
+
+    test_bool(dummy_invoked, false);
+    test_int(run_invoked, 1);
+
+    test_int(ctx.invoked, 2);
+    test_int(ctx.count, 3);
+    test_int(ctx.e[0], e1);
+    test_int(ctx.e[1], e2);
+    test_int(ctx.e[2], e3);
+
+    ecs_fini(world);
+}
