@@ -1371,6 +1371,240 @@ void OrderedChildren_get_ordered_children_from_prefab_instance_nested_children(v
     ecs_fini(world);
 }
 
+void OrderedChildren_prefab_w_nested_ordered_children(void) {
+    ecs_world_t *world = ecs_mini();
+
+    ECS_COMPONENT(world, Position);
+    ECS_TAG(world, Foo);
+    ECS_TAG(world, Bar);
+    ECS_TAG(world, Zoo);
+
+    ecs_entity_t p = ecs_new_w_id(world, EcsPrefab);
+    ecs_add_id(world, p, EcsOrderedChildren);
+
+    ecs_entity_t pc = ecs_new_w_pair(world, EcsChildOf, p);
+    ecs_add_id(world, pc, EcsOrderedChildren);
+    ecs_set(world, pc, Position, {10, 20});
+    ecs_add(world, pc, Foo);
+
+    ecs_entity_t pcc1 = ecs_new_w_pair(world, EcsChildOf, pc);
+    ecs_set(world, pcc1, Position, {11, 21});
+    ecs_add(world, pcc1, Bar);
+
+    ecs_entity_t pcc2 = ecs_new_w_pair(world, EcsChildOf, pc);
+    ecs_set(world, pcc2, Position, {12, 22});
+    ecs_add(world, pcc2, Zoo);
+
+    ecs_entity_t pcc3 = ecs_new_w_pair(world, EcsChildOf, pc);
+    ecs_set(world, pcc3, Position, {13, 23});
+    ecs_add(world, pcc3, Bar);
+
+    ecs_entity_t i = ecs_new_w_pair(world, EcsIsA, p);
+    ecs_entities_t children = ecs_get_ordered_children(world, i);
+    test_int(children.count, 1);
+
+    ecs_entity_t ic = children.ids[0];
+    test_assert(ic != 0);
+    test_assert(ecs_has(world, ic, Foo));
+    {
+        const Position *ptr = ecs_get(world, ic, Position);
+        test_assert(ptr != NULL);
+        test_int(ptr->x, 10);
+        test_int(ptr->y, 20);
+    }
+
+    ecs_entities_t gchildren = ecs_get_ordered_children(world, ic);
+    test_int(gchildren.count, 3);
+
+    test_assert(gchildren.ids[0] != 0);
+    test_assert(ecs_has(world, gchildren.ids[0], Bar));
+    {
+        const Position *ptr = ecs_get(world, gchildren.ids[0], Position);
+        test_assert(ptr != NULL);
+        test_int(ptr->x, 11);
+        test_int(ptr->y, 21);
+    }
+
+    test_assert(gchildren.ids[1] != 0);
+    test_assert(ecs_has(world, gchildren.ids[1], Zoo));
+    {
+        const Position *ptr = ecs_get(world, gchildren.ids[1], Position);
+        test_assert(ptr != NULL);
+        test_int(ptr->x, 12);
+        test_int(ptr->y, 22);
+    }
+
+    test_assert(gchildren.ids[2] != 0);
+    test_assert(ecs_has(world, gchildren.ids[2], Bar));
+    {
+        const Position *ptr = ecs_get(world, gchildren.ids[2], Position);
+        test_assert(ptr != NULL);
+        test_int(ptr->x, 13);
+        test_int(ptr->y, 23);
+    }
+
+    ecs_fini(world);
+}
+
+void OrderedChildren_prefab_w_nested_ordered_children_2(void) {
+    ecs_world_t *world = ecs_mini();
+
+    ECS_COMPONENT(world, Position);
+    ECS_TAG(world, Foo);
+    ECS_TAG(world, Bar);
+    ECS_TAG(world, Zoo);
+
+    ecs_entity_t p = ecs_new_w_id(world, EcsPrefab);
+    ecs_add_id(world, p, EcsOrderedChildren);
+
+        ecs_entity_t pc_1 = ecs_new_w_pair(world, EcsChildOf, p);
+        ecs_add_id(world, pc_1, EcsOrderedChildren);
+        ecs_set(world, pc_1, Position, {10, 20});
+        ecs_add(world, pc_1, Foo);
+
+            ecs_entity_t pc1_c1 = ecs_new_w_pair(world, EcsChildOf, pc_1);
+            ecs_set(world, pc1_c1, Position, {11, 21});
+            ecs_add(world, pc1_c1, Bar);
+
+            ecs_entity_t pc1_c2 = ecs_new_w_pair(world, EcsChildOf, pc_1);
+            ecs_set(world, pc1_c2, Position, {12, 22});
+            ecs_add(world, pc1_c2, Zoo);
+
+            ecs_entity_t pc1_c3 = ecs_new_w_pair(world, EcsChildOf, pc_1);
+            ecs_set(world, pc1_c3, Position, {13, 23});
+            ecs_add(world, pc1_c3, Bar);
+
+        ecs_entity_t pc_2 = ecs_new_w_pair(world, EcsChildOf, p);
+        ecs_add_id(world, pc_2, EcsOrderedChildren);
+        ecs_set(world, pc_2, Position, {30, 40});
+        ecs_add(world, pc_2, Foo);
+
+            ecs_entity_t pc2_c1 = ecs_new_w_pair(world, EcsChildOf, pc_2);
+            ecs_set(world, pc2_c1, Position, {31, 41});
+            ecs_add(world, pc2_c1, Bar);
+
+            ecs_entity_t pc2_c2 = ecs_new_w_pair(world, EcsChildOf, pc_2);
+            ecs_set(world, pc2_c2, Position, {32, 42});
+            ecs_add(world, pc2_c2, Zoo);
+
+            ecs_entity_t pc2_c3 = ecs_new_w_pair(world, EcsChildOf, pc_2);
+            ecs_set(world, pc2_c3, Position, {33, 43});
+            ecs_add(world, pc2_c3, Bar);
+
+    ecs_entity_t i = ecs_new_w_pair(world, EcsIsA, p);
+    ecs_entities_t children = ecs_get_ordered_children(world, i);
+    test_int(children.count, 2);
+
+    {
+        ecs_entity_t ic = children.ids[0];
+        test_assert(ic != 0);
+        test_assert(ecs_has(world, ic, Foo));
+        {
+            const Position *ptr = ecs_get(world, ic, Position);
+            test_assert(ptr != NULL);
+            test_int(ptr->x, 10);
+            test_int(ptr->y, 20);
+        }
+
+        ecs_entities_t gchildren = ecs_get_ordered_children(world, ic);
+        test_int(gchildren.count, 3);
+
+        test_assert(gchildren.ids[0] != 0);
+        test_assert(ecs_has(world, gchildren.ids[0], Bar));
+        {
+            const Position *ptr = ecs_get(world, gchildren.ids[0], Position);
+            test_assert(ptr != NULL);
+            test_int(ptr->x, 11);
+            test_int(ptr->y, 21);
+        }
+
+        test_assert(gchildren.ids[1] != 0);
+        test_assert(ecs_has(world, gchildren.ids[1], Zoo));
+        {
+            const Position *ptr = ecs_get(world, gchildren.ids[1], Position);
+            test_assert(ptr != NULL);
+            test_int(ptr->x, 12);
+            test_int(ptr->y, 22);
+        }
+
+        test_assert(gchildren.ids[2] != 0);
+        test_assert(ecs_has(world, gchildren.ids[2], Bar));
+        {
+            const Position *ptr = ecs_get(world, gchildren.ids[2], Position);
+            test_assert(ptr != NULL);
+            test_int(ptr->x, 13);
+            test_int(ptr->y, 23);
+        }
+    }
+
+    {
+        ecs_entity_t ic = children.ids[1];
+        test_assert(ic != 0);
+        test_assert(ecs_has(world, ic, Foo));
+        {
+            const Position *ptr = ecs_get(world, ic, Position);
+            test_assert(ptr != NULL);
+            test_int(ptr->x, 30);
+            test_int(ptr->y, 40);
+        }
+
+        ecs_entities_t gchildren = ecs_get_ordered_children(world, ic);
+        test_int(gchildren.count, 3);
+
+        test_assert(gchildren.ids[0] != 0);
+        test_assert(ecs_has(world, gchildren.ids[0], Bar));
+        {
+            const Position *ptr = ecs_get(world, gchildren.ids[0], Position);
+            test_assert(ptr != NULL);
+            test_int(ptr->x, 31);
+            test_int(ptr->y, 41);
+        }
+
+        test_assert(gchildren.ids[1] != 0);
+        test_assert(ecs_has(world, gchildren.ids[1], Zoo));
+        {
+            const Position *ptr = ecs_get(world, gchildren.ids[1], Position);
+            test_assert(ptr != NULL);
+            test_int(ptr->x, 32);
+            test_int(ptr->y, 42);
+        }
+
+        test_assert(gchildren.ids[2] != 0);
+        test_assert(ecs_has(world, gchildren.ids[2], Bar));
+        {
+            const Position *ptr = ecs_get(world, gchildren.ids[2], Position);
+            test_assert(ptr != NULL);
+            test_int(ptr->x, 33);
+            test_int(ptr->y, 43);
+        }
+    }
+
+    ecs_fini(world);
+}
+
+void OrderedChildren_prefab_w_slots(void) {
+    ecs_world_t *world = ecs_mini();
+
+    ecs_entity_t p = ecs_new_w_id(world, EcsPrefab);
+    ecs_add_id(world, p, EcsOrderedChildren);
+
+    ecs_entity_t pc1 = ecs_new_w_pair(world, EcsChildOf, p);
+    ecs_add_pair(world, pc1, EcsSlotOf, p);
+    ecs_entity_t pc2 = ecs_new_w_pair(world, EcsChildOf, p);
+    ecs_add_pair(world, pc2, EcsSlotOf, p);
+    ecs_entity_t pc3 = ecs_new_w_pair(world, EcsChildOf, p);
+    ecs_add_pair(world, pc3, EcsSlotOf, p);
+
+    ecs_entity_t i = ecs_new_w_pair(world, EcsIsA, p);
+    ecs_entities_t children = ecs_get_ordered_children(world, i);
+    test_int(children.count, 3);
+    test_assert(ecs_get_target(world, i, pc1, 0) == children.ids[0]);
+    test_assert(ecs_get_target(world, i, pc2, 0) == children.ids[1]);
+    test_assert(ecs_get_target(world, i, pc3, 0) == children.ids[2]);
+
+    ecs_fini(world);
+}
+
 void OrderedChildren_recreate_named_child(void) {
     ecs_world_t *world = ecs_mini();
 
