@@ -521,6 +521,30 @@ void Enum_add_enum_class_constant(void) {
     test_assert(id == ecs.pair(r, c));
 }
 
+void Enum_add_singleton_enum_constant(void) {
+    flecs::world ecs;
+
+    ecs.component<StandardEnum>().add(flecs::Singleton);
+
+    ecs.add(StandardEnum::Red);
+
+    test_assert(ecs.has(StandardEnum::Red));
+    test_assert(!ecs.has(StandardEnum::Green));
+    test_assert(!ecs.has(StandardEnum::Blue));
+
+    ecs.add(StandardEnum::Green);
+
+    test_assert(!ecs.has(StandardEnum::Red));
+    test_assert(ecs.has(StandardEnum::Green));
+    test_assert(!ecs.has(StandardEnum::Blue));
+
+    ecs.add(StandardEnum::Blue);
+
+    test_assert(!ecs.has(StandardEnum::Red));
+    test_assert(!ecs.has(StandardEnum::Green));
+    test_assert(ecs.has(StandardEnum::Blue));
+}
+
 void Enum_replace_enum_constants(void) {
     flecs::world ecs;
 
@@ -664,7 +688,7 @@ void Enum_query_enum_constant(void) {
     auto e1 = ecs.entity().add(StandardEnum::Blue);
 
     auto q = ecs.query_builder()
-        .with<StandardEnum>(StandardEnum::Blue)
+        .with(StandardEnum::Blue)
         .build();
 
     int32_t count = 0;
@@ -677,6 +701,50 @@ void Enum_query_enum_constant(void) {
     test_int(count, 1);
 }
 
+void Enum_query_singleton_enum_constant(void) {
+    flecs::world ecs;
+
+    ecs.component<StandardEnum>().add(flecs::Singleton);
+
+    auto q = ecs.query_builder()
+        .with(StandardEnum::Blue)
+        .build();
+
+    int32_t count = 0;
+
+    q.each([&](flecs::iter& it, size_t index) {
+        count ++;
+    });
+
+    test_int(count, 0);
+
+    ecs.add(StandardEnum::Red);
+
+    q.each([&](flecs::iter& it, size_t index) {
+        count ++;
+    });
+
+    test_int(count, 0);
+
+    ecs.add(StandardEnum::Green);
+
+    q.each([&](flecs::iter& it, size_t index) {
+        count ++;
+    });
+
+    test_int(count, 0);
+
+    ecs.add(StandardEnum::Blue);
+
+    q.each([&](flecs::iter& it, size_t index) {
+        test_assert(it.src(0) == ecs.component<StandardEnum>());
+        test_assert(it.pair(0).second() == ecs.id(StandardEnum::Blue));
+        count ++;
+    });
+
+    test_int(count, 1);
+}
+
 void Enum_enum_type_from_stage(void) {
     flecs::world ecs;
 
