@@ -66,6 +66,43 @@ flecs::opaque<std::vector<T>, T> std_vector_support(flecs::world& world) {
     return ts;
 }
 
+template <typename T>
+flecs::opaque<std::optional<T>, T>
+std_optional_support(flecs::world &world) {
+  return flecs::opaque<std::optional<T>, T>()
+    .as_type(world.vector<T>())
+    .serialize(
+      [](const flecs::serializer *s, const std::optional<T> *data) {
+        if (*data) {
+          s->value(**data);
+        }
+        return 0;
+      })
+    .count([](const std::optional<T> *data) -> size_t {
+      return *data ? 1 : 0;
+    })
+    .resize([](std::optional<T> *data, size_t size) {
+      switch (size) {
+      case 0:
+        *data = std::nullopt;
+        break;
+      case 1:
+        if(!data->has_value()) {
+          *data = T();
+        }
+        break;
+      default:
+        assert(false);
+      }
+    })
+    .ensure_element(
+      [](std::optional<T> *data, size_t) {
+          if(!data->has_value()) {
+            *data = T();
+          }
+          return &data->value();
+        });
+}
 
 void Meta_struct(void) {
     flecs::world ecs;
@@ -1601,3 +1638,90 @@ void Meta_script_to_std_vector_std_string(void) {
     test_str(v.at(0).c_str(), "Hello");
     test_str(v.at(1).c_str(), "World");
 }
+
+void Meta_anonymous_opaque_as_type_parent(void) {
+    // Implement testcase
+}
+
+void Meta_named_opaque_as_type_parent(void) {
+    // Implement testcase
+}
+
+void Meta_parented_opaque_as_type_parent(void) {
+    // Implement testcase
+}
+
+void Meta_ser_deser_std_optional_int(void) {
+    flecs::world world;
+
+    world.component<std::optional<int>>()
+        .opaque(std_optional_support<int>);
+
+    std::optional<int> o = std::nullopt;
+    test_str(world.to_json(&o).c_str(), "[]");
+
+    o = 1;
+    test_str(world.to_json(&o).c_str(), "[1]");
+
+    world.from_json(&o, "[]");
+    test_str(world.to_json(&o).c_str(), "[]");
+
+    world.from_json(&o, "[2]");
+    test_str(world.to_json(&o).c_str(), "[2]");
+}
+
+void Meta_ser_deser_std_optional_std_vector_int(void) {
+    flecs::world world;
+
+    world.component<std::vector<int>>()
+        .opaque(std_vector_support<int>);
+
+    world.component<std::optional<std::vector<int>>>()
+        .opaque(std_optional_support<std::vector<int>>);
+
+    std::optional<std::vector<int>> o = std::nullopt;
+    test_str(world.to_json(&o).c_str(), "[]");
+
+    o = {1, 2, 3};
+    test_str(world.to_json(&o).c_str(), "[[1, 2, 3]]");
+
+    world.from_json(&o, "[]");
+    test_str(world.to_json(&o).c_str(), "[]");
+
+    world.from_json(&o, "[[4, 5, 6]]");
+    test_str(world.to_json(&o).c_str(), "[[4, 5, 6]]");
+}
+
+void Meta_ser_deser_std_optional_std_string(void) {
+    flecs::world world;
+
+    world.component<std::string>()
+        .opaque(std_string_support);
+
+    world.component<std::optional<std::string>>()
+        .opaque(std_optional_support<std::string>);
+
+    std::optional<std::string> o = std::nullopt;
+    test_str(world.to_json(&o).c_str(), "[]");
+
+    o = "hello world";
+    test_str(world.to_json(&o).c_str(), "[\"hello world\"]");
+
+    world.from_json(&o, "[]");
+    test_str(world.to_json(&o).c_str(), "[]");
+
+    world.from_json(&o, "[\"foo bar\"]");
+    test_str(world.to_json(&o).c_str(), "[\"foo bar\"]");
+}
+
+void Meta_ser_deser_alias(void) {
+    flecs::world world;
+    auto parent = world.entity();
+    world.entity().child_of(parent).set_alias("child");
+    auto str = world.to_json();
+    test_assert(world.lookup("child"));
+
+    flecs::world world2;
+    world2.from_json(str);
+    test_assert(world2.lookup("child"));
+}
